%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

% Bridge Loading Module to ContBeam
% HA/HB Loading crossing a bridge

% Example 10: 2-span 38 m bridge, HB loading with a particular point of 
% interest at 36.9 m from the start of the bridge
L = [38,38];
E = 30;
I = [600e10,600e10];
R = [-1,0,-1,0,-1,0];
step_size = 0.2;        % metres
mid_wheel_space = 6;    % 6, 11, 16, 21, or 26 m
HB_units = 45;          % Usually 30 - 45, but may be 25
POI = 36.9;             % Point of particular interest

npts = (sum(L)+mid_wheel_space+2*1.8)/step_size;
[out step] = run_HB(HB_units,mid_wheel_space,npts,L,E,I,R);
res = ppHAHBrun(out,step,POI);

% Example 11: 2-span 38 m bridge, KEL loading with a particular point of 
% interest at 36.9 m from the start of the bridge
L = [38,38];
E = 30;
I = [600e10,600e10];
R = [-1,0,-1,0,-1,0];
step_size = 0.2;        % metres
mid_wheel_space = 6;    % 6, 11, 16, 21, or 26 m
HB_units = 45;          % Usually 30 - 45, but may be 25
POI = 36.9;             % Point of particular interest

npts = sum(L)/step_size;
[out step] = run_KEL(npts,L,E,I,R);
res = ppHAHBrun(out,step,POI);

% Example 12: Bridge assessment of a 2-span 60 m long bridge for a special 
% vehicle of axle spacing and loads as defined below
L = [30,30];
E = 30;
I = [600e10,600e10];
R = [-1,0,-1,0,-1,0];
step_size = 0.2;        % metres
mid_wheel_space = 6;    % 6, 11, 16, 21, or 26 m
HB_units = 45;          % Usually 30 - 45, but may be 25
POI = 28.9;             % Point of particular interest

ax_space = [2.25,1.36,1.4,5,  1.5,1.5,1.5,1.5,1.5,1.5,1.5,1.5,1.5,1.5,1.5,1.5,1.5,1.5,1.5];
ax_weight = [ 80, 100,120,120,169,169,169,169,169,169,169,169,169,169,169,169,169,169,169];
[out step] = run_Special(ax_space,ax_weight,npts,L,E,I,R);

% Example 13: HA/HB loading for the previous bridge assessment of a 2-span 
% 60 m long bridge
L = [30,30];
E = 30;
I = [600e10,600e10];
R = [-1,0,-1,0,-1,0];
step_size = 0.2;        % metres
mid_wheel_space = 6;    % 6, 11, 16, 21, or 26 m
HB_units = 45;          % Usually 30 - 45, but may be 25
POI = 28.9;             % Point of particular interest

npts = sum(L)/step_size;
[out step] = run_KEL(npts,L,E,I,R);
res = ppHAHBrun(out,step,POI);