%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

function [out step] = run_KEL(np,L,E,I,R)
% This function runs a knife-edge-load across the given bridge forming an
% output matrix of moments and shears
no_points = np;
step = sum(L)/no_points;

for i = 0:no_points
    a = i*step;
    span = 1; load = 120;
    % check load is on the bridge
    % and assign to correct span if it is.
    for k = 1:length(L)
        if a > L(k)
            % put it on the next span
            a = a - L(k);
            span = k+1;
            if span > length(L)
                a = 0; load = 0; 
            end
        end
    end
    LM = [span,2,load,a,0];

    temp = CBA(L,E,I,R,LM,'r');
    [nr nc] = size(temp);
    out(1,i+2) = i*step;
    if i == 0
        out(2:nr+1,1) = temp(:,1);
    end
    out(2:nr+1,i+2) = temp(:,2);
end
