%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

function [out step] = run_Special(axs,axw,np,L,E,I,R)
% This runs a specially defined truck across the given bridge using CBA
% axs is a vector of axle-spacings
% axw is a vector of axle-weights

no_points = np;
no_axles = length(axs);
step = (sum(L)+sum(axs(2:no_axles)))/no_points;

for i = 0:no_points
    ax(1) = i*step;
    for iax = 2:no_axles
        ax(iax) = ax(iax-1) - axs(iax-1);
    end
    
    % check load is on the bridge
    % and assign to correct span if it is.
    for j = 1:no_axles
        span = 1; load = axw(j);
        if ax(j) < 0
            ax(j) = 0; load = 0;
        else
            for k = 1:length(L)
                if ax(j) > L(k)
                    % put it on the next span
                    % loads off the end of the beam are assigned to the 
                    % imaginary next span and will not be assigned to any 
                    % span of the analysis - see LM_span.m
                    ax(j) = ax(j) - L(k);
                    span = k+1;
                    if span > length(L)
                        a(j) = 0; load = 0; 
                    end
                end
            end
        end
        LM(j,:) = [span,2,load,ax(j),0];
    end
    temp = CBA(L,E,I,R,LM,'r'); % matrix format: 
    (x, M, V, d)
    [nr nc] = size(temp);
    out(1,i+2) = i*step;
    if i == 0
        out(2:nr+1,1) = temp(:,1);
    end
    out(2:nr+1,i+2) = temp(:,2);
end
